Changelog
=========

This changelog is still scarce since DueCredit is still in a prototype state.
For full list of changes, just introspect its git repository and release
tags' messages for now.

0.1.0
-----

- Initial release.  Provides API prototype and basic `summary` command.
